
//
//	Nev@Delap.com, October 2000
//
//	Goes through the string removing
//	extra whitespace, and replacing
//	whitespace and commas that are
//	within quotes with escapes.
//	Also makes sure there are no spaces
//	around |, so that flags in the controls
//	are pulled out as a single token.
//

#include "stdafx.h"
#include "Tokenizer.h"

const char WHITESPACE_ESCAPE=1;
const char COMMA_ESCAPE		=2;

Tokenizer::Tokenizer(CString str)
  : m_str(str)
{

	m_str.Replace("\r"," ");
	m_str.Replace("\n"," ");

	while(m_str.Find(" |")!=-1)
	{
		m_str.Replace(" |","|");
	}

	while(m_str.Find("| ")!=-1)
	{
		
		m_str.Replace("| ","|");
	}

	bool bOutsideQuotes=true;

	for(int i=0;i<m_str.GetLength()-1;i++)
	{
		if(m_str.GetAt(i)=='"')
		{
			bOutsideQuotes=!bOutsideQuotes;
		}

		if(bOutsideQuotes)
		{
									// Outside quotes treat
									// commas and tabs as
									// whitespace.
			if(m_str.GetAt(i)==',')
			{
				m_str.SetAt(i,' ');
			}

			if(m_str.GetAt(i)=='\t')
			{
				m_str.SetAt(i,' ');
			}

			if(m_str.GetAt(i)==' ' && m_str.GetAt(i+1)==' ')
			{
				m_str=m_str.Left(i)+m_str.Right(m_str.GetLength()-i-1);
				i--;
			}
		}
		else
		{
			if(m_str.GetAt(i)==' ')
			{
				m_str.SetAt(i,WHITESPACE_ESCAPE);
			}

			if(m_str.GetAt(i)==',')
			{
				m_str.SetAt(i,COMMA_ESCAPE);
			}
		}
	}

	ASSERT(m_str.Find("  ")==-1);
}

CString Tokenizer::NextToken(int iSkip)
{
	CString strToken;

	while(iSkip>-1)
	{
		strToken=m_str;

		int iWhitespace=strToken.Find(' ');

		if(iWhitespace==-1)
		{
			break;
		}
		
		strToken=strToken.Left(iWhitespace);
		m_str=m_str.Right(m_str.GetLength()-iWhitespace-1);

		iSkip--;
	}

	strToken.Replace(WHITESPACE_ESCAPE,' ');
	strToken.Replace(COMMA_ESCAPE,',');

	return strToken;
}

CString	Tokenizer::NextTokenWithoutQuotes(int iSkip)
{
	CString strToken=NextToken(iSkip);

	if(strToken.Left(1)=="\"")
	{
		strToken=strToken.Right(strToken.GetLength()-1);
	}

	if(strToken.Right(1)=="\"")
	{
		strToken=strToken.Left(strToken.GetLength()-1);
	}

	return strToken;
}

CString	Tokenizer::NextTokenAdjustedInteger(double dMultiplier,int iSkip)
{
	CString strToken=NextToken(iSkip);

	long lToken=atoi(strToken);

	lToken=long(lToken*dMultiplier);

	strToken.Format("%d",lToken);

	return strToken;
}

void Tokenizer::PushBackToken(CString strToken)
{
	strToken.Replace(' ',WHITESPACE_ESCAPE);
	strToken.Replace(',',COMMA_ESCAPE);

	m_str=strToken+" "+m_str;
}
